@@ -20,7 +20,7 @@ import botocore.exceptions
 from .common import *
 from .resolver import ContainerResolver
 
-logger = logging.getLogger()
+logger = logging.getLogger("ssm-tools.ecs-session")
 
 def parse_args(argv):
     """
@@ -32,7 +32,7 @@ def parse_args(argv):
     add_general_parameters(parser)
 
     group_container = parser.add_argument_group('Container Selection')
-    group_container.add_argument('CONTAINER', nargs='?', help='Task ID, Container Name or IP address')
+    group_container.add_argument('CONTAINER', nargs=argparse.ZERO_OR_MORE, help='Task ID, Container Name or IP address. Use multiple keywords (e.g. Task Name and IP) to narrow down ambiguous selections.')
     group_container.add_argument('--list', '-l', dest='list', action="store_true", help='List available containers configured for ECS RunTask')
     group_container.add_argument('--cluster', dest='cluster', metavar='CLUSTER', help='Specify an ECS cluster. (optional)')
 
@@ -83,26 +83,25 @@ def main():
     ## Split command line to main args and optional command to run
     args, extras = parse_args(sys.argv[1:])
 
-    global logger
-    logger = configure_logging("ecs-session", args.log_level)
+    configure_logging(args.log_level)
 
     try:
         if args.list:
             ContainerResolver(args).print_list()
-            quit(0)
+            sys.exit(0)
 
-        container = ContainerResolver(args).resolve_container(args.CONTAINER)
+        container = ContainerResolver(args).resolve_container(keywords=args.CONTAINER)
 
         if not container:
-            logger.warning("Could not find any container matching '%s'", args.CONTAINER)
-            quit(1)
+            logger.warning("Could not find any container matching: %s", " AND ".join(args.CONTAINER))
+            sys.exit(1)
 
         start_session(container, args, args.command)
 
     except (botocore.exceptions.BotoCoreError,
             botocore.exceptions.ClientError) as e:
         logger.error(e)
-        quit(1)
+        sys.exit(1)
 
 if __name__ == "__main__":
     main()
